This package is show about me
=============================

PyPi: https://pypi.org/project/ingsirapob/

Hello this package is show about me

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install ingsirapob

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

\```python from ingsirapob import sirapob user = Sirapob() #ประกาศคลาส
user.show_name() # โชว์ชื่อ user.play_game() #เกมที่เล่นอยู่ตอนนี้
user.about() # เกี่ยวกับ user.show_art() # art

พัฒนาโดย: สิรภพ
